// --------------------------------------------------------------------------------------------------------------------------------
// example.cpp - example for using the Logger class
// --------------------------------------------------------------------------------------------------------------------------------

#include "logger.h"

// --------------------------------------------------------------------------------------------------------------------------------

void	generateRandomNumbers()
{
	LOGFUNC("generateRandomNumbers()");

	// Just fill in a buffer of 256 characters with random data

	char	buffer[256];
	for (unsigned int i = 0; i < 256; i++)
	{
		buffer[i] = rand() % 256;
	}

	// Log the output

	HEX(buffer, sizeof(buffer));
}

// --------------------------------------------------------------------------------------------------------------------------------

void	logTypes()
{
	LOGFUNC("logTypes()");

	// Log a few different types...

	LOG("This is an [I]nfo line (notice the 'I' on the far left of the log");
	string	data("data data data");
	LOG("Here is some [D]ata: " + data, Logger::LOG_DATA);
	LOG("A log with the [W]arning flag set", Logger::LOG_WARN);
	LOG("Here we have an [E]rror entry in the log", Logger::LOG_ERR);
	LOG("And finally a [!] critical error", Logger::LOG_CRIT);
}

// --------------------------------------------------------------------------------------------------------------------------------

void	recursion()
{
	LOGFUNC("recursion()");

	static	int	recursionLevel;

	if (recursionLevel == 3)
	{
		LOG("We're inside a recusive routine that has gone three levels deep");
	}

	if (recursionLevel < 3)
	{
		recursionLevel++;
		recursion();
	}
}

// --------------------------------------------------------------------------------------------------------------------------------

void	generateRawData()
{
	LOGFUNC("generateRawData()");

	RAW("\nThis is a test\n  This is only a test\n    This is nothing more than a test of the RAW (unformatted) logging output.\n\n");
}

// --------------------------------------------------------------------------------------------------------------------------------

int	main()
{
	LOGFUNC("main()");

	// Log some various types of entries to the log

	logTypes();

	// Log some recursive routines

	recursion();

	// Do some indentation. We'll use braces to limit scope of temporary objects that handle the indention for us. When the
	// braces terminate, so will the scope of the temporary objects, which automatically "pops" the indention stack

	LOG("Here we have some indentation without having to call multiple routines");

	{
		LOGBLOCK("Indention level 1");
		{
			LOGBLOCK("Indention level 2");
			LOG("Hello, from the depths of multiple indentation levels");
		}
	}

	// Let's log some RAW data...

	generateRawData();

	// Some random numbers, displayed in hex

	generateRandomNumbers();

	// Spit out another line, just for fun

	logger += "Are we having fun yet? :)";

	// Done

	return 0;
}

// --------------------------------------------------------------------------------------------------------------------------------
